@@ -5,16 +5,44 @@ use warnings;
 
 use autodie;
 
-our $VERSION = '0.0.5';
-
-use MooX qw/late/;
+our $VERSION = '0.2.0';
 
 use Getopt::Long qw( GetOptionsFromArray );
 use Pod::Usage;
 
 use App::Du::Analyze::Filter;
 
-has argv => (isa => 'ArrayRef', is => 'rw');
+sub argv
+{
+    my $self = shift;
+
+    if (@_)
+    {
+        $self->{argv} = shift;
+    }
+
+    return $self->{argv};
+}
+
+sub new
+{
+    my $class = shift;
+
+    my $self = bless {}, $class;
+
+    $self->_init(@_);
+
+    return $self;
+}
+
+sub _init
+{
+    my ($self, $args) = @_;
+
+    $self->argv($args->{argv});
+
+    return;
+}
 
 sub run
 {
@@ -103,7 +131,7 @@ directories.
 
 =head1 VERSION
 
-version 0.0.5
+version 0.2.0
 
 =head1 DESCRIPTION
 
@@ -126,6 +154,10 @@ The constructor. Accepts the @ARGV array as a parameter and parses it.
 
 Runs the application.
 
+=head2 $app->argv()
+
+B<For internal use.>
+
 =head1 AUTHOR
 
 Shlomi Fish <shlomif@cpan.org>
