@@ -3,14 +3,83 @@ package App::Du::Analyze::Filter;
 use strict;
 use warnings;
 
-use MooX qw/late/;
+sub _my_all
+{
+    my $cb = shift;
 
-use List::MoreUtils qw/all/;
+    foreach my $x (@_)
+    {
+        if (not $cb->(local $_ = $x))
+        {
+            return 0;
+        }
+    }
 
-has '_prefix' => (isa => 'Str', is => 'ro', init_arg => 'prefix');
-has '_depth' => (isa => 'Int', is => 'ro', init_arg => 'depth');
-has '_should_sort' => (isa => 'Bool', is => 'ro', init_arg => 'should_sort',
-default => sub { 1; },);
+    return 1;
+}
+
+sub new
+{
+    my $class = shift;
+
+    my $self = bless {}, $class;
+
+    $self->_init(@_);
+
+    return $self;
+}
+
+sub _depth
+{
+    my $self = shift;
+
+    if (@_)
+    {
+        $self->{_depth} = shift;
+    }
+
+    return $self->{_depth};
+}
+
+sub _prefix
+{
+    my $self = shift;
+
+    if (@_)
+    {
+        $self->{_prefix} = shift;
+    }
+
+    return $self->{_prefix};
+}
+
+sub _should_sort
+{
+    my $self = shift;
+
+    if (@_)
+    {
+        $self->{_should_sort} = shift;
+    }
+
+    return $self->{_should_sort};
+}
+
+sub _init
+{
+    my ($self, $args) = @_;
+
+    $self->_prefix($args->{prefix});
+    $self->_depth($args->{depth});
+    $self->_should_sort(1);
+
+    if (exists($args->{should_sort}))
+    {
+        $self->_should_sort($args->{should_sort});
+    }
+
+    return;
+}
 
 sub filter
 {
@@ -39,7 +108,7 @@ sub filter
             if (
                 (@path_to_test == @prefix_to_test + $depth)
                     and
-                (all { $path_to_test[$_] eq $prefix_to_test[$_] } (0 .. $#prefix_to_test))
+                (_my_all (sub { $path_to_test[$_] eq $prefix_to_test[$_] }, (0 .. $#prefix_to_test)))
             )
             {
                 $path =~ s#\A/##;
@@ -75,7 +144,7 @@ App::Du::Analyze::Filter - filter algorithm for L<App::Du::Analyze>
 
 =head1 VERSION
 
-version 0.0.5
+version 0.2.0
 
 =head1 NOTE
 
